@@ -64,7 +64,7 @@ def detect_irrelevant_regulator(regulators, rule, threshold=0.1):
             dif = np.abs(rule[j] - rule[i])
             max_dif = max(dif, max_dif)
             tot_dif = tot_dif + dif
-            signed_tot_dif = signed_tot_dif + rule[i] - rule[j]
+            signed_tot_dif = signed_tot_dif + rule[j] - rule[i]
         max_difs.append(max_dif)
         tot_difs.append(tot_dif)
         signed_tot_difs.append(signed_tot_dif)
@@ -104,8 +104,8 @@ def get_rules_scvelo(
     data,
     data_t1,
     vertex_dict,
-    plot=True,
-    show_plot=True,
+    plot=False,
+    show_plot=False,
     save_plot=True,
     threshold=0.1,
     save_dir="rules",
@@ -234,6 +234,7 @@ def get_rules_scvelo(
             rules[gene] = rules[gene][importance_order]
             # rules[gene] = smooth_rule(rules[gene], regulators, tot_regulator_relevance, np.max(heat,axis=0))
 
+            #strengths and signed_strengths should have child nodes as rows with columns as parent nodes
             strengths.loc[gene] = tot_regulator_relevance
             signed_strengths.loc[gene] = signed_tot_regulator_relevance
 
@@ -246,7 +247,7 @@ def get_rules_scvelo(
                     data,
                     save_dir=save_dir,
                     save=save_plot,
-                    show_plot=True,
+                    show_plot=show_plot,
                     hlines=hlines,
                 )
 
@@ -260,7 +261,14 @@ def get_rules_scvelo(
 # plot = boolean - make the resulting plot
 # threshold = float from 0.0 to 1.0, used as threshold for removing irrelevant regulators. 0 removes nothing. 1 removes all.
 def get_rules(
-    data, vertex_dict, plot=False, threshold=0.1, directory="rules", hlines=None
+    data, 
+    vertex_dict, 
+    plot=False, 
+    threshold=0.1, 
+    save_dir="rules", 
+    save_plot = True,
+    show_plot = False,
+    hlines=None
 ):
     v_names = dict()
     for vertex_name in list(vertex_dict):
@@ -268,6 +276,9 @@ def get_rules(
     nodes = list(vertex_dict)
     rules = dict()
     regulators_dict = dict()
+    strengths = pd.DataFrame(index=nodes, columns=nodes)
+    signed_strengths = pd.DataFrame(index=nodes, columns=nodes)
+
     for gene in nodes:
         print(gene)
         # for each node of the network
@@ -383,6 +394,8 @@ def get_rules(
 
             rules[gene] = rules[gene][importance_order]
             # rules[gene] = smooth_rule(rules[gene], regulators, tot_regulator_relevance, np.max(heat,axis=0))
+            strengths.loc[gene] = tot_regulator_relevance
+            signed_strengths.loc[gene] = signed_tot_regulator_relevance
 
             if plot:
                 plot_rule(
@@ -391,15 +404,14 @@ def get_rules(
                     regulators,
                     heat,
                     data,
-                    directory=directory,
+                    save_dir=save_dir,
+                    save=save_plot,
+                    show_plot=show_plot,
                     hlines=hlines,
                 )
-        else:
-            fig = plt.figure()
-            plt.savefig(os.path.join(directory, "%s.pdf" % gene))
-            plt.clf()
-            plt.close()
-    return rules, regulators_dict
+
+
+    return rules, regulators_dict, strengths, signed_strengths
 
 
 def save_rules(rules, regulators_dict, fname="rules.txt", delimiter="|"):
